import pandas as pd
from sqlalchemy.sql import text

def truncate_and_write_sql(engine, df, table, schema='stg', if_exists='append', multi=False, truncate=True):
    write_to_sql(engine, df, table, schema, if_exists, multi)
    truncate_sql(engine, table)
    write_to_sql(engine, df, table, schema, if_exists, multi)


def truncate_sql(engine, table):
    # Truncate table before writing
    engine.execute(text(f'''TRUNCATE TABLE [stg].[{table}]''').execution_options(autocommit=True))


def write_to_sql(engine, df, table, schema, if_exists, multi=False):
    try:
        df.to_sql(table,
                  schema=schema,
                  con=engine,
                  if_exists=if_exists,
                  chunksize=2100//df.shape[1]-1 if multi else 1000,
                  method='multi' if multi else None,
                  index=False)
    except:
        df.to_sql(table,
                  schema=schema,
                  con=engine,
                  if_exists=if_exists,
                  chunksize=1000 if multi else 2100//df.shape[1]-1,
                  method=None if multi else 'multi',
                  index=False)


import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name = 'truncate-and-write-to-sql',
    version = '0.0.0',
    author = 'Markus Pettersen',
    author_email = 'mp.markus94@gmail.com',
    description = 'Truncate existing table and write to the table with new entries',
    long_description = long_description,
    url = 'https://github.com/MPettersen/truncate_and_write_to_sql',
    packages = setuptools.find_packages(),
    classifiers = [
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires = '>=3.8',
)